==> haskell-aeson-yaml-1.1.0.1-187-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-UQxOngeJoYD3wieavrF1u
key:                  aeson-yaml-1.1.0.1-UQxOngeJoYD3wieavrF1u
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  5bb01d1a7f845c5b9781c7835ccb0754
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.2.8/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-UQxOngeJoYD3wieavrF1u
depends:
    aeson-2.1.2.1-3SHm0QLDkzeAZY7TeIq3Kg base-4.16.4.0
    bytestring-0.11.4.0 text-1.2.5.0
    unordered-containers-0.2.20-8WFaf62MVyiL1uC2m0h0zY
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-yaml-1.1.0.1-188-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-9iTlhaApvhNHy3m5BkDhZk
key:                  aeson-yaml-1.1.0.1-9iTlhaApvhNHy3m5BkDhZk
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  f8e8c0701237150bcf1fa651a629b16e
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.2.8/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-9iTlhaApvhNHy3m5BkDhZk
depends:
    aeson-2.1.2.1-3SHm0QLDkzeAZY7TeIq3Kg base-4.16.4.0
    bytestring-0.11.4.0 text-1.2.5.0
    unordered-containers-0.2.20-8WFaf62MVyiL1uC2m0h0zY
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
